@@ -1,4 +1,3 @@
-/* $Id: mutt.h,v 2.1 1998/12/12 09:15:54 roessler Exp $ */
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -190,6 +189,7 @@ enum
   M_OR,
   M_TO,
   M_CC,
+  M_COLLAPSED,
   M_SUBJECT,
   M_FROM,
   M_DATE,
@@ -236,7 +236,6 @@ enum
 {
 
 
-  OPT_USEMAILCAP,
   OPT_PRINT,
   OPT_INCLUDE,
   OPT_DELETE,
@@ -292,6 +291,8 @@ enum
   OPTHELP,
   OPTHIDDENHOST,
   OPTIGNORELISTREPLYTO,
+  OPTIMPLICITAUTOVIEW,
+  OPTMAILCAPSANITIZE,
   OPTMARKERS,
   OPTMARKOLD,
   OPTMENUSCROLL,	/* scroll menu instead of implicit next-page */
@@ -350,7 +351,6 @@ enum
   OPTFORCEREDRAWPAGER,	/* (pseudo) used to force a redraw in the pager */
   OPTSORTSUBTHREADS,	/* (pseudo) used when $sort_aux changes */
   OPTNEEDRESCORE,	/* (pseudo) set when the `score' command is used */
-  OPTSORTCOLLAPSE,	/* (pseudo) used by mutt_sort_headers() */
   OPTUSEHEADERDATE,	/* (pseudo) used by edit-message */
   OPTATTACHMSG,		/* (pseudo) used by attach-message */
   
@@ -494,7 +494,6 @@ typedef struct header
 {
 
   unsigned int mime : 1;    /* has a Mime-Version header? */
-  unsigned int mailcap : 1; /* requires mailcap to display? */
   unsigned int flagged : 1; /* marked important? */
   unsigned int tagged : 1;
   unsigned int deleted : 1;
@@ -641,6 +640,7 @@ typedef struct
 
 
 #define M_PENDINGPREFIX (1<<2) /* prefix to write, but character must follow */
+#define M_WEED          (1<<3) /* weed headers even when not in display mode */
 
 #define state_set_prefix(s) ((s)->flags |= M_PENDINGPREFIX)
 #define state_reset_prefix(s) ((s)->flags &= ~M_PENDINGPREFIX)
