@@ -1,4 +1,3 @@
-static const char rcsid[]="$Id: mx.c,v 2.3 1998/12/21 12:38:57 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -106,15 +105,22 @@ retry_lock:
   mutt_clear_error();
   if((r = invoke_dotlock(path, flags, retry)) == DL_EX_EXIST)
   {
-    char msg[LONG_STRING];
-
-    snprintf(msg, sizeof(msg), _("Lock count exceeded, remove lock for %s?"),
-	     path);
-    if(retry && mutt_yesorno(msg, 1) == 1)
+    if (!option (OPTNOCURSES))
     {
-      flags |= DL_FL_FORCE;
-      retry--;
-      goto retry_lock;
+      char msg[LONG_STRING];
+      
+      snprintf(msg, sizeof(msg), _("Lock count exceeded, remove lock for %s?"),
+	       path);
+      if(retry && mutt_yesorno(msg, 1) == 1)
+      {
+	flags |= DL_FL_FORCE;
+	retry--;
+	goto retry_lock;
+      }
+    } 
+    else
+    {
+      mutt_error ( _("Can't dotlock %s.\n"), path);
     }
   }
   return (r == DL_EX_OK ? 0 : -1);
@@ -697,8 +703,10 @@ static int sync_mailbox (CONTEXT *ctx)
 #endif /* USE_IMAP */
   }
 
+#if 0
   if (!ctx->quiet && rc == -1)
     mutt_error ( _("Could not synchronize mailbox %s!"), ctx->path);
+#endif
   
 #ifdef BUFFY_SIZE
   if (tmp && tmp->new == 0)
@@ -796,9 +804,16 @@ int mx_close_mailbox (CONTEXT *ctx)
     {
       if (ctx->hdrs[i]->read && !ctx->hdrs[i]->deleted)
       {
-	mutt_append_message (&f, ctx, ctx->hdrs[i], 0, CH_UPDATE_LEN);
-	ctx->hdrs[i]->deleted = 1;
-	ctx->deleted++;
+	if (mutt_append_message (&f, ctx, ctx->hdrs[i], 0, CH_UPDATE_LEN) == 0)
+	{
+	  ctx->hdrs[i]->deleted = 1;
+	  ctx->deleted++;
+	}
+	else
+	{
+	  mx_close_mailbox (&f);
+	  return -1;
+	}
       }
     }
 
@@ -988,9 +1003,7 @@ int mx_sync_mailbox (CONTEXT *ctx)
     }
 
     mx_update_tables(ctx, 1);
-    set_option (OPTSORTCOLLAPSE);
     mutt_sort_headers (ctx, 1); /* rethread from scratch */
-    unset_option (OPTSORTCOLLAPSE);
   }
 
   return (rc);
@@ -1302,10 +1315,6 @@ void mx_update_context (CONTEXT *ctx)
 
 
 
-
-
-    if (mutt_needs_mailcap (h->content))
-      h->mailcap = 1;
   if (h->flagged)
     ctx->flagged++;
   if (h->deleted)
