@@ -1,4 +1,3 @@
-static const char rcsid[]="$Id: pattern.c,v 2.1 1998/12/23 15:57:00 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -77,6 +76,7 @@ Flags[] =
   { 'T', M_TAG,			0,		NULL },
   { 't', M_TO,			0,		eat_regexp },
   { 'U', M_UNREAD,		0,		NULL },
+  { 'v', M_COLLAPSED,		0,		NULL },
   { 'x', M_REFERENCE,		0,		eat_regexp },
   { 'z', M_SIZE,		0,		eat_range },
   { 0 }
@@ -845,6 +845,8 @@ mutt_pattern_exec (struct pattern_t *pat, pattern_exec_flag flags, CONTEXT *ctx,
       return (pat->not ^ match_user (pat->alladdr, h->env->to, h->env->cc));
     case M_PERSONAL_FROM:
       return (pat->not ^ match_user (pat->alladdr, h->env->from, NULL));
+    case M_COLLAPSED:
+      return (pat->not ^ (h->collapsed && h->num_hidden > 1));
   }
   mutt_error (_("error: unknown op %d (report this error)."), pat->op);
   return (-1);
