@@ -1,4 +1,3 @@
-static const char rcsid[]="$Id: thread.c,v 2.1 1998/12/16 13:22:30 roessler Exp $";
 
 /*
  * WORK IN PROGRESS ALERT: Daniel Eisenbud <daniel@math.berkeley.edu>
@@ -49,18 +48,25 @@ static int need_display_subject (CONTEXT *ctx, HEADER *tree)
 {
   HEADER *tmp;
 
+  /* if our subject is different from our parent's, display it */
   if (tree->subject_changed)
     return (1);
+
+  /* if our subject is different from that of our closest previously displayed
+   * sibling, display the subject */
   for (tmp = tree->prev; tmp; tmp = tmp->prev)
   {
     if (tmp->virtual >= 0 || (tmp->collapsed && (!ctx->pattern || tmp->limited)))
     {
-      if (!tmp->subject_changed)
-	return (0);
+      if (tmp->subject_changed)
+	return (1);
       else
 	break;
     }
   }
+  
+  /* if there is a parent-to-child subject change anywhere between us and our
+   * closest displayed ancestor, display the subject */
   for (tmp = tree->parent; tmp; tmp = tmp->parent)
   {
     if (tmp->virtual >= 0 || (tmp->collapsed && (!ctx->pattern || tmp->limited)))
@@ -68,7 +74,9 @@ static int need_display_subject (CONTEXT *ctx, HEADER *tree)
     else if (tmp->subject_changed)
       return (1);
   }
-  return (0);
+  
+  /* if we have no visible parent or previous sibling, display the subject */
+  return (1);
 }
 
 /* determines whether a later sibling or the child of a later 
@@ -741,6 +749,7 @@ int _mutt_traverse_thread (CONTEXT *ctx, HEADER *cur, int flag)
 
   if (flag & (M_THREAD_COLLAPSE | M_THREAD_UNCOLLAPSE))
   {
+    cur->pair = 0; /* force index entry's color to be re-evaluated */
     cur->collapsed = flag & M_THREAD_COLLAPSE;
     if (cur->virtual != -1)
     {
@@ -767,6 +776,7 @@ int _mutt_traverse_thread (CONTEXT *ctx, HEADER *cur, int flag)
   {
     if (flag & (M_THREAD_COLLAPSE | M_THREAD_UNCOLLAPSE))
     {
+      cur->pair = 0; /* force index entry's color to be re-evaluated */
       cur->collapsed = flag & M_THREAD_COLLAPSE;
       if (!roothdr && CHECK_LIMIT)
       {
